##  Focus on the Conceptual Data Layer
To effectively manage and integrate your data, it's important to understand the different data layers within Collibra :
  * Conceptual Data Layer: This layer represents the highest data level, such as data domains and data concepts (e.g., Customer, Employee, Prospect, etc.)
  * Logical Data Layer: Data entities and data attributes (e.g., The customer lives on a street with a zip code).
  * Physical Data Layer: Schemas, tables, columns (e.g., the specific database and column for customer addresses).


For more details, see [Collibra Documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fproductresources.collibra.com%2Fdocs%2Fcollibra%2Flatest%2FContent%2FCatalog%2FGuidedStewardship%2FOperatingModel%2Fto_catalog-om.htm "https://productresources.collibra.com/docs/collibra/latest/Content/Catalog/GuidedStewardship/OperatingModel/to_catalog-om.htm")
Focus on gaining visibility into Collibra’s conceptual data layer, as this is most meaningful for enterprise architecture management. This primarily involves syncing business assets and their subcategories—data domains and data concepts—into SAP LeanIX.
**Note**
Avoid syncing everything to SAP LeanIX, as it swamps your inventory and does not help answer questions of value for your Enterprise Architecture team. Focus on aligning and analyzing only the data that adds value to your objectives while Collibra remains the source of truth for data.
